﻿using UnityEngine;
using System.Collections;

public class AnimateSprite : MonoBehaviour
{
    public int columns = 2;
    public int rows = 2;
    public float framesPerSecond = 10f;
    public Vector3 spriteScaleRight;
    public Vector3 spriteScaleLeft;
    public MeshRenderer _renderer;
    public Texture walkCycle;
    public Texture idle;
    public bool moving;

    //the current frame to display
    private int index = 0;

    private void Awake()
    {
        if (_renderer == null)
            _renderer = GetComponent<MeshRenderer>();

        spriteScaleRight = transform.localScale;
        spriteScaleLeft = new Vector3(-1 * spriteScaleRight.x,
                                      spriteScaleRight.y,
                                      spriteScaleRight.z);
    }

    public void Move()
    {
        if (moving == true)
            return;

        _renderer.material.mainTexture = walkCycle;
        Animate();
    }

    public void Idle()
    {
        moving = false;
        StopCoroutine(updateTiling());
        

        _renderer.material.mainTexture = idle;
        _renderer.material.SetTextureScale("_MainTex", Vector2.one);
        _renderer.sharedMaterial.SetTextureOffset("_MainTex", Vector2.zero);
        
    }

    void Animate()
    {
        if (moving == true)
            return;

        StartCoroutine(updateTiling());

        //set the tile size of the texture (in UV units), based on the rows and columns
        Vector2 size = new Vector2(1f / columns, 1f / rows);
        _renderer.sharedMaterial.SetTextureScale("_MainTex", size);
    }

    void StopAnimation()
    {
        StopCoroutine(updateTiling());
    }

    private IEnumerator updateTiling()
    {
        moving = true;

        while (moving)
        {
            //move to the next index
            index++;
            if (index >= rows * columns)
                index = 0;

            //split into x and y indexes
            Vector2 offset = new Vector2((float)index / columns - (index / columns), //x index
                                          (index / columns) / (float)rows);          //y index

            _renderer.sharedMaterial.SetTextureOffset("_MainTex", offset);

            yield return new WaitForSeconds(1f / framesPerSecond);
        }

    }
}