﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

[RequireComponent(typeof(BoxCollider2D))]
public class Goal : MonoBehaviour {

    public int activeNodes = 0;
    private bool transmitting = false;
    public ShootableNode[] dataNodes;
    public ParticleSystem progressParticles;
    public ParticleSystem transmissionParticles;
    public HazaardSpawner onesAndZeroesSpawner;
    public BoxCollider2D boxCollider2D;

    [Header("Sound")]
    public AudioSource audioSource;
    public AudioClip progressSound;
    public AudioClip completesound;
    float pitchStep;
    float minPitch = 0.28f;
    float maxPitch = 0.58f;


    private void Awake()
    {
        boxCollider2D.isTrigger = true;
        pitchStep = (maxPitch - minPitch) / 3;
    }

    public void ActivateNode()
    {
        if (audioSource != null && audioSource.isPlaying == false)
            audioSource.Play();

        if (progressParticles.isPlaying == false)
            progressParticles.Play();

        activeNodes++;

        if (activeNodes == dataNodes.Length && transmitting == false)
            EnableTransmission();

        if(activeNodes >= dataNodes.Length - 3 && activeNodes < dataNodes.Length)
        {
            audioSource.pitch = minPitch + (dataNodes.Length - activeNodes) * pitchStep;

        } else if(activeNodes == dataNodes.Length)
        {
            audioSource.pitch = maxPitch;
        }

        
    }

    public void EnableTransmission()
    {
        transmitting = true;
        transmissionParticles.Play();
        progressParticles.Stop();
    }

    private void OnTriggerStay2D(Collider2D collision)
    {
        if (transmitting == true)
        {
            if (collision.gameObject.CompareTag("Player"))
            {
                Player.instance.hud.DisplayNotification("Press \""
                                                        + Player.instance.inputConfig.confirm.ToString()
                                                        + "\" to transmit.");

                if (Input.GetKeyUp(Player.instance.inputConfig.confirm))
                {
                    audioSource.Stop();
                    audioSource.clip = completesound;
                    audioSource.Play();

                    Debug.Log("got confirm key up");
                    Player.instance.GetComponent<Rigidbody2D>().constraints = RigidbodyConstraints2D.FreezePositionX;
                    Player.instance.mainCamera.maximumHeight = GetComponentInChildren<HazaardEndPoint>().transform.position.y;
                    Player.instance.TransmitToNextLevel();
                    onesAndZeroesSpawner.enabled = true;
                }
            }
        }
    }

}
