﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class ShootableNode : MonoBehaviour {

    //for data nodes only
    public Goal dataGoal;

    //for connector nodes only
    public GameObject platformConnectionRay;

    public bool inUse;
    public ProjectileType nodeType = ProjectileType.platformMaker;

    private void Start()
    {
        GetComponent<SpriteRenderer>().color = Player.instance.projectilePool.projectiles[0].GetColour(nodeType);
        if(nodeType == ProjectileType.data && dataGoal == null)
        {
            dataGoal = FindObjectOfType<Goal>();
        }
    }

    private void Select()
    {
        //particleSystem.Play();
    }

    private void Deselect()
    {
        //particleSystem.Stop();
    }

    private void OnTriggerEnter2D(Collider2D collision)
    {
        if (collision.GetComponent<Projectile>() == null)
            return;

        Projectile p = collision.GetComponent<Projectile>();
        if (p.projectileType != ProjectileType.platformMaker && nodeType == ProjectileType.platformMaker)
            return;

        if (inUse)
        {
            return;
        }

        if (nodeType == ProjectileType.platformMaker)
        {
            inUse = true;

            if (Player.instance.selectedNode == null || Player.instance.selectedNode.nodeType != nodeType)
            {
                Player.instance.selectedNode = this;
            }
            else if (Player.instance.selectedNode != this)
            {
                Debug.Log("activating ray");
                Vector3 direction = Player.instance.selectedNode.transform.position - transform.position;
                float distance = Vector2.Distance(Player.instance.selectedNode.transform.position, transform.position);

                GameObject ray = NodeLinks.instance.connectionRayPool.ActivateObject(transform.position);
                ray.GetComponent<NodeConnectionRay>().TryConnection(this, Player.instance.selectedNode, direction);
                ray.transform.up = -direction;

                /*
                ContactFilter2D filter = new ContactFilter2D();
                filter.NoFilter();
                
                RaycastHit2D[] hit = new RaycastHit2D[] { };
                 int num = Physics2D.Raycast(transform.position, direction, filter, hit,
                                      Vector2.Distance(Player.instance.selectedNode.transform.position, transform.position));
                 


               int num = Physics2D.Raycast(transform.position, Vector2.right * direction.x, filter, hit, distance);

                Debug.DrawRay(transform.position, direction, Color.magenta, 2f, false);

                //@TODO setup polygon colliders on terrain
                Debug.Log(num + " num hits in overlapBox");

                if (num > 0)
                {
                    foreach (RaycastHit2D h in hit)
                    {
                        Debug.Log(h.transform.tag);
                        if (h.transform.CompareTag(tag) == false)
                        {
                            return;
                        }
                    }
                }
                */


                // MakeConnection(direction);

            }
        } else if(nodeType == ProjectileType.data && p.projectileType == ProjectileType.data && inUse == false)
        {
            inUse = true;
            dataGoal.ActivateNode();
        }
    }

    public void MakeBridgeConnection(Vector3 offset, ShootableNode targetNode)
    {
        GameObject go = Instantiate(NodeLinks.instance.platformPrefab, transform.position + (offset * 0.5f),
                                Quaternion.identity);

        go.transform.right = offset;

        NodeBridge nodeBridge = go.GetComponent<NodeBridge>();
        float xSize = Vector3.Distance(transform.position, targetNode.transform.position);
        nodeBridge.spriteRenderer.size = new Vector2(xSize, nodeBridge.spriteRenderer.size.y);
        nodeBridge.boxCollider.size = nodeBridge.spriteRenderer.size;

        nodeBridge.parentNodes[0] = this;
        nodeBridge.parentNodes[1] = targetNode;

        inUse = true;
        targetNode.inUse = true;

        Player.instance.selectedNode = null;
    }
}
