﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;

public class Player : MonoBehaviour {

    public int hitPoints = 3;
    public float recoilTime = 1f;
    public bool recoiling = false;

    [Header("Player State")]
    public static Player instance;
    public IPlayerState currentState;
    [HideInInspector] public IPlayerIdle idleState;
    public InputConfig inputConfig = new InputConfig();
    

    [Header("References")]
    public ShootableNode selectedNode;
    public ProjectilePool projectilePool;
    public ProjectileType projectileType = ProjectileType.platformMaker;
    public Transform gunMuzzle;
    public CameraFollow mainCamera;
    public HUD hud;
    public Transform arm;
    
    [Header("Sprites")]
    public Sprite regularGunArm;
    public Sprite recoilGunArm;
    public SpriteRenderer gunArm;
    public AnimateSprite spriteAnimator;
    public Vector3 shoulderMountLeft;
    public Vector3 shoulderMountRight;

    [Header("Colours")]
    public Color normalTint = Color.white;
    public Color transitionStartColour = Color.cyan;
    public Color transitionEndColour = new Color(0, 1, 1, 0);
    public float transitionDuration = 3f;

    [Header("Sounds")]
    public AudioSource audioSource;
    public AudioClip projectileSound;

    [Header("Collider")]
    public BoxCollider2D boxCollider2D;
    public Vector2 leftFacingBoxOffset;
    public Vector2 rightFacingBoxOffset;

    void Awake()
    {
        if (instance != null)
            DestroyImmediate(this);

        instance = this;

        currentState = idleState;
    }

    private void Start()
    {
        hud.SetLaserDisplay(projectilePool.projectiles[0].GetColour(projectileType));
        hud.SetCurrentLaserText(projectileType);
    }

    // Update is called once per frame
    void Update () {
        arm.right = Input.mousePosition - mainCamera.halfScreenSize;

        if(Input.GetKeyUp(inputConfig.firePrimaryProjectile) && recoiling == false)
        {
            if (projectileSound != null && audioSource != null)
            {
               
                audioSource.Play();
            }

            recoiling = true;
            projectilePool.ActivateProjectile(gunMuzzle.position, arm.right);
            StartCoroutine(Recoil());
        }

        if(Input.GetKeyUp(inputConfig.toggleLaser))
        {
            projectileType += 1;

            if (projectileType == ProjectileType.Length)
                projectileType = 0;

            hud.SetLaserDisplay(projectilePool.projectiles[0].GetColour(projectileType));
            hud.SetCurrentLaserText(projectileType);
        }
	}

    IEnumerator Recoil()
    {
        gunArm.sprite = recoilGunArm;

        float timer = Time.time + recoilTime;

        while(timer > Time.time)
        {
            yield return null;
        }

        gunArm.sprite = regularGunArm;
        recoiling = false;
        yield return null;
    }

    public void TransmitToNextLevel()
    {
        recoiling = true;
        GetComponent<AAPM>().rb.gravityScale = -.1f;

        StartCoroutine(TransmissionTransition());
    }

    IEnumerator TransmissionTransition()
    {
        float timer = transitionDuration + Time.time;
        while (timer > Time.time) {
            spriteAnimator._renderer.material.color = Color.Lerp(transitionStartColour, transitionEndColour, Time.time / timer);
            gunArm.color = Color.Lerp(transitionStartColour, transitionEndColour, Time.time / timer);
            yield return null;
        }
        ProgressTracker.instance.currentLevel++;
        SceneManager.LoadScene(ProgressTracker.instance.currentLevel, LoadSceneMode.Single);
        yield return null;
    }

    public void TakeDamage(int damage)
    {
        hitPoints -= damage;
        hud.DisplayHP();

        if (hitPoints <= 0)
            Lose();
    }

    /*
     * Lose the game
     * Loads the losing screen
    */
    public void Lose() {
        SceneManager.LoadScene("LoseScreen", LoadSceneMode.Single);
    }
}
