﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Projectile : MonoBehaviour {

    public float speed = 3f;
    public int damage = 1;
    public float life = 5f;
    public SpriteRenderer spriteRenderer;
    public Rigidbody2D rb;
    public Transform myTransform;
    public ProjectileType projectileType = ProjectileType.damaging;

    [Header("Type Colours")]
    public Color damagingColour = Color.red;
    public Color platformMakerColour = Color.green;
    public Color platformBreakerColour = Color.yellow;
    public Color dataColour = Color.cyan;

    private void Awake()
    {
        if(myTransform == null)
            myTransform = transform;
    }

    private void SetColour()
    {
        switch (projectileType)
        {
            case ProjectileType.damaging:
                spriteRenderer.color = damagingColour;
                break;

            case ProjectileType.platformMaker:
                spriteRenderer.color = platformMakerColour;
                break;

            case ProjectileType.platformBreaker:
                spriteRenderer.color = platformBreakerColour;
                break;

            default:
                spriteRenderer.color = Color.magenta;
                break;

        }
    }

    public Color GetColour(ProjectileType projectileType)
    {
        switch (projectileType)
        {
            case ProjectileType.damaging:
                return damagingColour;
                

            case ProjectileType.platformMaker:
                return platformMakerColour;
                

            case ProjectileType.platformBreaker:
                return platformBreakerColour;
                

            default:
                return Color.magenta;
                
        }
    }

    private void OnEnable()
    {
        SetColour();
        
        rb.AddForce(myTransform.right * speed, ForceMode2D.Impulse);
        StartCoroutine(lifeTimer());
    }

    private void Disable()
    {
        rb.velocity = Vector2.zero;
        gameObject.SetActive(false);
    }

    IEnumerator lifeTimer()
    {
        float start = Time.time;
        while(Time.time - start < life)
        {
            yield return null;
        }

        Disable();
        yield return null;
    }

    private void OnCollisionEnter2D(Collision2D collision)
    {
        Disable();
    }

}

public enum ProjectileType
{
    platformMaker,
    platformBreaker,
    data,
    damaging,
    Length
}
