﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class ProjectilePool : MonoBehaviour {

    public int poolSize = 10;
    public GameObject projectilePrefab;
    public List<Projectile> projectiles = new List<Projectile>();
    public bool canGrow = false;

	void Awake () {
		for(int i = 0; i <= poolSize; i++)
        {
            projectiles.Add( Instantiate(projectilePrefab).GetComponent<Projectile>() );
            projectiles[i].gameObject.transform.SetParent(transform);
            projectiles[i].gameObject.SetActive(false);
        }
	}

    public void ActivateProjectile(Vector3 position, Vector3 right)
    {
        Projectile projectile = getInactive();

        if (projectile == null)
            return;

        projectile.projectileType = Player.instance.projectileType;
        projectile.myTransform.right = right;
        projectile.gameObject.SetActive(true);
        projectile.rb.position = position;

    }
	
	private Projectile getInactive()
    {
        Projectile projectile = null;
        
        foreach(Projectile p in projectiles)
        {
            if(p.gameObject.activeSelf == false)
            {
                projectile = p;
                break;
            }
        }

        if(projectile == null && canGrow == true)
        {
            projectile = IncreasePool();
        } else if(projectile == null)
        {
            return null;
        }

        return projectile;
    }

    public Projectile IncreasePool()
    {
        projectiles.Add(Instantiate(projectilePrefab).GetComponent<Projectile>());
        projectiles[projectiles.Count - 1].transform.SetParent(transform);
        return projectiles[projectiles.Count - 1];
    }
}
